double f_(double*, double*, double*,  double*, double*, int*);
void cubtri_(double*, double*, int*, double*, double*, 
	     int*, double*, int*, double*, double*, double*, int*, int*);
void pnpoly_(double*, double*, double*, double*, int*, int*);
void circumcircle(double*, double*, double*, double*);
void constrained(double*, int*, double*, double*, double*, int*, int*, int*);
void adapt_poly(double*, int*, double*, int*, double*, int*, double*, 
	       double*, double*, double*, double*, int*, int*, 
	       int*, double*);
